@@ -1,87 +1,93 @@
-#include <Rcpp.h>
-using namespace Rcpp;
-
-//'@title Kernel functions
-//'@name kernel
+//' @title
+//' Kernel functions
+//' @name kernel
+//' 
+//' @description
+//' `r lifecycle::badge('deprecated')`
 //'
-//'@description
-//'Kernel functions that transform observed p-values or their support according
-//'to [HSU], [HSD], [AHSU], [AHSD] and [HBR-\eqn{\lambda}]. The output is used
-//'by \code{\link{discrete.BH}} or \code{\link{DBR}}, respectively.
-//'Additionally, \code{kernel.DBH.crit}, \code{kernel.ADBH.crit} and
-//'\code{kernel.DBR.crit} compute and return the critical constants. The end
-//'user should not use these functions directly.
-//'
-//'@details
-//'When computing critical constants under step-down, that is, when using
-//'\code{kernel.DBH.crit}, \code{kernel.ADBH.crit} or \code{kernel.DBR.crit}
-//'with \code{stepUp = FALSE} (i.e. the step-down case), we still need to get
-//'transformed p-values to compute the adjusted p-values.
-//'
-//'This version: 2019-11-15.
-//'
-//'@seealso
-//'\code{\link{discrete.BH}}, \code{\link{DiscreteFDR}},
-//'\code{\link{DBR}}
-//'
-//'@templateVar pCDFlist TRUE
-//'@templateVar stepf FALSE
-//'@templateVar pvalues TRUE
-//'@templateVar stepUp TRUE
-//'@templateVar alpha TRUE
-//'@templateVar lambda TRUE
-//'@templateVar support TRUE
-//'@templateVar sorted_pv TRUE
-//'@templateVar raw.pvalues FALSE
-//'@templateVar direction FALSE
-//'@templateVar ret.crit.consts FALSE
-//'@templateVar adaptive FALSE
-//'@template param 
-//'
-//'@template example
-//'@examples
-//'
-//'alpha <- 0.05
-//'
-//'# Compute the step functions from the supports
-//'
-//'# We stay in a step-down context, where pv.numer = pv.denom,
-//'# for the sake of simplicity
-//'
-//'# If not searching for critical constants, we use only the observed p-values
-//'sorted.pvals <- sort(raw.pvalues)
-//'y.DBH.fast <- kernel_DBH_fast(pCDFlist, sorted.pvals)
-//'y.ADBH.fast <- kernel_ADBH_fast(pCDFlist, sorted.pvals)
-//'# transformed values
-//'y.DBH.fast
-//'y.ADBH.fast
-//'
-//'# compute transformed support
-//'pv.list <- sort(unique(unlist(pCDFlist)))
-//'y.DBH.crit <- kernel_DBH_crit(pCDFlist, pv.list, sorted.pvals)
-//'y.ADBH.crit <- kernel_ADBH_crit(pCDFlist, pv.list, sorted.pvals)
-//'y.DBR.crit <- kernel_DBR_crit(pCDFlist, pv.list, sorted.pvals)
-//'# critical constants
-//'y.DBH.crit$crit.consts
-//'y.ADBH.crit$crit.consts
-//'y.DBR.crit$crit.consts
-//'# The following exist only for step-down direction or DBR
-//'y.DBH.crit$pval.transf
-//'y.ADBH.crit$pval.transf
-//'y.DBR.crit$pval.transf
-//'
-//'@return
-//'For \code{kernel.DBH.fast}, \code{kernel.ADBH.fast} and
-//'\code{kernel.DBR.fast}, a vector of transformed p-values is returned.
-//'\code{kernel.DBH.crit,} \code{kernel.ADBH.crit} and \code{kernel.DBR.crit}
-//'return a list object with critical constants (\code{$crit.consts}) and
-//'transformed p-values (\code{$pval.transf}), but if \code{stepUp = FALSE},
-//'there are critical values only.
+//' Kernel functions that transform observed p-values or their support according
+//' to \[HSU\], \[HSD\], \[AHSU\], \[AHSD\] and \[HBR-\eqn{\lambda}\]. The
+//' output is used by [discrete.BH] or [DBR], respectively.
+//' `kernel_DBH_crit`, `kernel_ADBH_crit` and `kernel_DBR_crit` additionally
+//' compute and return the critical constants. 
+//' The end user should not use these functions directly.
+//' 
+//' **Note**: In future versions, these functions will no longer be exported to
+//' the global namespace. Instead, they will be purely internal functions and
+//' will have to be called directly via `:::`, e.g.
+//' `DiscreteFDR:::kernel_DBH_fast()`.
+//' 
+//' @details
+//' When computing critical constants under step-down, that is, when using
+//' `kernel_DBH_crit`, `kernel_ADBH_crit` or `kernel_DBR_crit` with
+//' `stepUp = FALSE` (i.e. the step-down case), we still need to get transformed
+//' p-values to compute the adjusted p-values.
+//' 
+//' @seealso
+//' [discrete.BH], [fast.Discrete], [DBR]
+//' 
+//' @templateVar pCDFlist TRUE
+//' @templateVar stepf FALSE
+//' @templateVar pvalues TRUE
+//' @templateVar stepUp TRUE
+//' @templateVar alpha FALSE
+//' @templateVar alpha2 TRUE
+//' @templateVar lambda TRUE
+//' @templateVar support TRUE
+//' @templateVar sorted_pv TRUE
+//' @templateVar raw.pvalues FALSE
+//' @templateVar direction FALSE
+//' @templateVar ret.crit.consts FALSE
+//' @templateVar adaptive FALSE
+//' @template param 
+//' 
+//' @template example
+//' @examples
+//' 
+//' alpha <- 0.05
+//' 
+//' # Compute the step functions from the supports
+//' 
+//' # We stay in a step-down context, where pv.numer = pv.denom,
+//' # for the sake of simplicity
+//' 
+//' # If not searching for critical constants, we use only the observed p-values
+//' sorted.pvals <- sort(raw.pvalues)
+//' y.DBH.fast <- kernel_DBH_fast(pCDFlist, sorted.pvals)
+//' y.ADBH.fast <- kernel_ADBH_fast(pCDFlist, sorted.pvals)
+//' # transformed values
+//' y.DBH.fast
+//' y.ADBH.fast
+//' 
+//' # compute transformed support
+//' pv.list <- sort(unique(unlist(pCDFlist)))
+//' y.DBH.crit <- kernel_DBH_crit(pCDFlist, pv.list, sorted.pvals)
+//' y.ADBH.crit <- kernel_ADBH_crit(pCDFlist, pv.list, sorted.pvals)
+//' y.DBR.crit <- kernel_DBR_crit(pCDFlist, pv.list, sorted.pvals)
+//' # critical constants
+//' y.DBH.crit$crit.consts
+//' y.ADBH.crit$crit.consts
+//' y.DBR.crit$crit.consts
+//' # The following exist only for step-down direction or DBR
+//' y.DBH.crit$pval.transf
+//' y.ADBH.crit$pval.transf
+//' y.DBR.crit$pval.transf
+//' 
+//' @return
+//' For `kernel.DBH.fast`, `kernel.ADBH.fast` and `kernel.DBR.fast`, a vector
+//' of transformed p-values is returned. `kernel.DBH.crit`, `kernel.ADBH.crit`
+//' `kernel.DBR.crit` return a list with critical constants (`$crit.consts`)
+//' and transformed p-values (`$pval.transf`), but if `stepUp = FALSE`, there
+//' are critical values only.
+//' 
 
 // fast step function evaluation
 // step function is represented by a single numeric vector under the conditions
 // a) f(x) = x and b) x is sorted
 // this is much faster than passing and evaluating R step function objects
+#include <Rcpp.h>
+using namespace Rcpp;
+
 NumericVector stepfun(const NumericVector &x, const NumericVector &sfun){
   // index variables and vector lengths
   int pos = 0, size = sfun.length(), len = x.length();
@@ -542,7 +548,7 @@ NumericVector kernel_DBR_fast(const List &pCDFlist, const NumericVector &pvalues
 // [[Rcpp::export]]
 List kernel_DBR_crit(const List &pCDFlist, const NumericVector &pvalues, const NumericVector &sorted_pv, const double lambda = 0.05, const double alpha = 0.05){
   // number of tests
-  int numTests = pCDFlist.length(), k_star;
+  int numTests = pCDFlist.length(), k_star = 0;
   // critical values indices
   IntegerVector crit(numTests);
   // transformed p-values
